@@ -1,10 +1,17 @@
-import Queue, tg, uuid
-from progress import asyncjobs_progress_status
+from __future__ import absolute_import
+
+try:
+    import queue
+except ImportError:
+    import Queue as queue
+
+import tg, uuid
+from .progress import asyncjobs_progress_status
 
 class AsyncJobQueue(object):
     def __init__(self):
         super(AsyncJobQueue, self).__init__()
-        self.queue = Queue.Queue()
+        self.queue = queue.Queue()
 
     def get(self):
         return self.queue.get()
@@ -14,7 +21,7 @@ class AsyncJobQueue(object):
         self.queue.task_done()
 
     def perform(self, what, args, params):
-        uid = str(uuid.uuid1())
+        uid = 'asyncjob_%s' % str(uuid.uuid1())
         asyncjobs_progress_status.track(uid)
         self.queue.put({'callable':what,
                         'args':args,
